#!/usr/bin/python
import mcidasx
import os
import sys

def main(argv):

    if len(argv) < 3:
        print ' Must specify a station and time'
        return
    else:
        station = argv[1]
        time = argv[2]

    os.environ['PATH']   = "%s:%s/mcidas/bin:/home/mcidas/bin" % (os.environ['HOME'],os.environ['PATH'])
    os.environ['MCPATH'] = "%s/workshop/mcidas/data:/home/mcidas/data" % os.environ['HOME']

    mcOutput = run_mcidas(station,time)
    dewPTdepression = get_dewPT(mcOutput)
    dewPTdepression = "{:6.2f}".format(dewPTdepression)
    print ' '
    print 'Dew point depression for ' + station + ' = ' + dewPTdepression

def run_mcidas(station,time):
#
# Create McIDAS environment and run commands
#
    mcenv = mcidasx.mcidas.mcenv()
    mcenv.logon('WKSP 1234')

    datalocString='ADD RTPTSRC NOAAPORT.SSEC.WISC.EDU'
    datalocOut = mcenv.dataloc(datalocString)

    sfclistString = station + ' TIME=' + time
    sfclistOut = mcenv.sfclist(sfclistString)

#
# Break output into list
#
    sfclistOutput = mccmdout2list(sfclistOut.stdout)
    return sfclistOutput

def mccmdout2list(mcoutput):
#
# Inputs output from a McIDAS command and creates a list of lines
#
    line = ''
    count = 0
    lineList = []
    for char in mcoutput:
        if char != '\n':
             line = line + char
        else:
             lineList.append(line)
             count = count + 1
             line = ''
    return lineList

def get_dewPT(outputList):
#
# Remove header and use only hourly observation
#
    outputList.pop(0)
    outputList.pop(0)
    outputList.pop(0)

    recCount = 0
    runningTot = 0
    for line in outputList:
        record = line.split()
        if 'Number' in record[0]:
            break
        elif 'S' in record[0]:
            pass
        else:
            temperature = float(record[4])
            dewPT = float(record[5])
            print temperature, dewPT

    dewPTdepression = temperature - dewPT
    return dewPTdepression
        
if __name__ == "__main__":
    main(sys.argv)
