#!/usr/bin/python
import mcidasx
import os
import sys

def main(argv):

    if len(argv) < 2:
        print ' Must specify a station '
        return
    else:
        station = argv[1]

    os.environ['PATH']   = "%s:%s/mcidas/bin:/home/mcidas/bin" % (os.environ['HOME'],os.environ['PATH'])
    os.environ['MCPATH'] = "%s/workshop/mcidas/data:/home/mcidas/data" % os.environ['HOME']

    mcOutput = run_mcidas(station)
    average = get_average(mcOutput)
    average = "{:6.2f}".format(average)
    print ' '
    print '24 hour temperture average for ' + station + ' = ' + average

def run_mcidas(station):
#
# Create McIDAS environment and run commands
#
    mcenv = mcidasx.mcidas.mcenv()
    mcenv.logon('WKSP 1234')

    datalocString='ADD RTPTSRC NOAAPORT.SSEC.WISC.EDU'
    datalocOut = mcenv.dataloc(datalocString)

    print station
    sfclistString = station + ' 24 '
    sfclistOut = mcenv.sfclist(sfclistString)

#
# Break output into list
#
    sfclistOutput = mccmdout2list(sfclistOut.stdout)
    return sfclistOutput

def mccmdout2list(mcoutput):
#
# Inputs output from a McIDAS command and creates a list of lines
#
    line = ''
    count = 0
    lineList = []
    for char in mcoutput:
        if char != '\n':
             line = line + char
        else:
             lineList.append(line)
             count = count + 1
             line = ''
    return lineList

def get_average(outputList):
#
# Remove header and average only hourly observations
#
    outputList.pop(0)
    outputList.pop(0)
    outputList.pop(0)

    recCount = 0
    runningTot = 0
    for line in outputList:
        record = line.split()
        if 'Number' in record[0]:
            break
        elif 'S' in record[0]:
            pass
        else:
            print record[4]
            runningTot = runningTot + float(record[4])
            recCount = recCount + 1

    temperatureAverage = runningTot / recCount
    return temperatureAverage
        
if __name__ == "__main__":
    main(sys.argv)
